@@ -4,29 +4,34 @@ build_time_vars = {'ABIFLAGS': '',
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALIGNOF_LONG': 8,
+ 'ALIGNOF_MAX_ALIGN_T': 16,
  'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wsign-compare',
+ 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.11',
- 'BLDLIBRARY': 'libpython3.11.a',
+ 'BINLIBDEST': '/usr/lib/python3.12',
+ 'BLDLIBRARY': 'libpython3.12.a',
  'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,-O1',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
+ 'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall',
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
+ 'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
+                          './Modules/cjkcodecs/cjkcodecs.h',
+ 'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
@@ -41,28 +46,25 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'build_alias=x86_64-linux-gnu' 'LDFLAGS=-Wl,-O1'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.11',
+ 'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/src/Python-3.11.14/coverage.info',
+ 'COVERAGE_INFO': '/src/Python-3.12.12/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/src/Python-3.11.14/lcov-report',
+ 'COVERAGE_REPORT': '/src/Python-3.12.12/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
-                            '--title "CPython 3.11 LCOV report [commit $(shell '
+                            '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include',
  'CXX': 'g++',
- 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                   '-DHAVE_UINT128_T=1',
- 'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
- 'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
+ 'DEEPFREEZE_DEPS': './Tools/build/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.11 '
-             '/usr/lib/python3.11/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.11',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.12 '
+             '/usr/lib/python3.12/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.12',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.11/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.12/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -75,6 +77,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DSYMUTIL': '',
+ 'DSYMUTIL_PATH': '',
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
@@ -84,15 +88,13 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'upgrade',
  'EXE': '',
  'EXEMODE': 755,
- 'EXPAT_CFLAGS': '-I./Modules/expat',
- 'EXPAT_LDFLAGS': '-lm Modules/expat/libexpat.a',
+ 'EXENAME': '/usr/bin/python3.12',
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-311-x86_64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-312-x86_64-linux-gnu.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 0,
  'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
@@ -184,6 +186,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DUP3': 1,
  'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_EDITLINE_READLINE_H': 0,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
  'HAVE_EPOLL_CREATE1': 1,
@@ -206,6 +209,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FDOPENDIR': 1,
  'HAVE_FDWALK': 0,
  'HAVE_FEXECVE': 1,
+ 'HAVE_FFI_CLOSURE_ALLOC': 1,
+ 'HAVE_FFI_PREP_CIF_VAR': 1,
+ 'HAVE_FFI_PREP_CLOSURE_LOC': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
  'HAVE_FORK1': 0,
@@ -303,11 +309,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
- 'HAVE_LIBGDBM_COMPAT': 0,
  'HAVE_LIBIEEE': 0,
  'HAVE_LIBINTL_H': 1,
- 'HAVE_LIBNDBM': 0,
- 'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBSQLITE3': 1,
@@ -321,6 +324,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
+ 'HAVE_LINUX_FS_H': 1,
  'HAVE_LINUX_LIMITS_H': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
@@ -343,8 +347,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 1,
- 'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
+ 'HAVE_MINIX_CONFIG_H': 0,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
  'HAVE_MKFIFOAT': 1,
@@ -354,6 +358,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 1,
  'HAVE_NANOSLEEP': 1,
+ 'HAVE_NCURSESW': 1,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDBM_H': 0,
  'HAVE_NDIR_H': 0,
@@ -361,12 +366,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETDB_H': 1,
  'HAVE_NETINET_IN_H': 1,
  'HAVE_NETPACKET_PACKET_H': 1,
+ 'HAVE_NET_ETHERNET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
  'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENDIR': 1,
  'HAVE_OPENPTY': 1,
+ 'HAVE_PANEL_H': 1,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
  'HAVE_PIPE': 1,
@@ -396,6 +403,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
+ 'HAVE_READLINE_READLINE_H': 1,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -434,6 +442,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SETITIMER': 1,
  'HAVE_SETJMP_H': 1,
  'HAVE_SETLOCALE': 1,
+ 'HAVE_SETNS': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
  'HAVE_SETPRIORITY': 1,
@@ -472,8 +481,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
  'HAVE_STAT_TV_NSEC2': 0,
- 'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
+ 'HAVE_STDIO_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
  'HAVE_STRFTIME': 1,
@@ -518,6 +527,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 1,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
@@ -551,12 +561,13 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 1,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
- 'HAVE_TTYNAME': 1,
+ 'HAVE_TTYNAME_R': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
+ 'HAVE_UNSHARE': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -586,45 +597,54 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.11 '
-                   '/usr/include/python3.11',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.12 '
+                   '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.11',
+ 'INCLUDEPY': '/usr/include/python3.12',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.11.a',
+ 'INSTSONAME': 'libpython3.12.a',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'g++ -shared',
+ 'LDCXXSHARED': 'g++ -shared -Wl,-O1 -Wl,-O1',
  'LDFLAGS': '-Wl,-O1 -Wl,-O1',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.11.a',
+ 'LDLIBRARY': 'libpython3.12.a',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,-O1',
- 'LDVERSION': '3.11',
+ 'LDVERSION': '3.12',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.11',
+ 'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-I./Modules/expat -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                    '-Wall -std=c11 -Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration '
+ 'LIBEXPAT_CFLAGS': '-I./Modules/expat -fno-strict-overflow -Wsign-compare '
+                    '-DNDEBUG -g -O3 -Wall -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
- 'LIBFFI_INCLUDEDIR': '',
+ 'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+                   '-std=c11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include -fPIC',
+ 'LIBHACL_HEADERS': '\\',
+ 'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
+ 'LIBHACL_SHA2_HEADERS': '\\',
+ 'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                    '-Wall -std=c11 -Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration '
+                    '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
+                    '-DNDEBUG -g -O3 -Wall -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-fPIC',
  'LIBMPDEC_HEADERS': '\\',
@@ -632,17 +652,17 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.11/config-3.11-x86_64-linux-gnu',
+ 'LIBPL': '/usr/lib/python3.12/config-3.12-x86_64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.11.a',
- 'LIBRARY_DEPS': 'libpython3.11.a',
+ 'LIBRARY': 'libpython3.12.a',
+ 'LIBRARY_DEPS': 'libpython3.12.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
- 'LINK_PYTHON_DEPS': 'libpython3.11.a',
+ 'LINK_PYTHON_DEPS': 'libpython3.12.a',
  'LINK_PYTHON_OBJS': '\\',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -653,18 +673,32 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.11',
+ 'MACHDESTLIB': '/usr/lib/python3.12',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
- 'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
-                   '_codecs  _collections  errno  _io  itertools  _sre  '
-                   '_thread  time  _weakref  _abc  _functools  _locale  '
-                   '_operator  _stat  _symtable  pwd  xxsubtype',
+ 'MODBUILT_NAMES': 'array  _asyncio  _bisect  _contextvars  _csv  _heapq  '
+                   '_json  _lsprof  _opcode  _pickle  _queue  _random  '
+                   '_struct  _xxsubinterpreters  _xxinterpchannels  _zoneinfo  '
+                   'audioop  math  cmath  _statistics  _datetime  _decimal  '
+                   'binascii  _bz2  _lzma  zlib  _gdbm  readline  _md5  _sha1  '
+                   '_sha2  _sha3  _blake2  pyexpat  _elementtree  _codecs_cn  '
+                   '_codecs_hk  _codecs_iso2022  _codecs_jp  _codecs_kr  '
+                   '_codecs_tw  _multibytecodec  unicodedata  _crypt  fcntl  '
+                   'grp  mmap  ossaudiodev  _posixsubprocess  resource  '
+                   'select  _socket  spwd  syslog  termios  _posixshmem  '
+                   '_multiprocessing  _ctypes  _curses  _curses_panel  '
+                   '_sqlite3  _ssl  _hashlib  _uuid  xxsubtype  _xxtestfuzz  '
+                   '_testbuffer  _testinternalcapi  _testcapi  _testclinic  '
+                   '_testimportmultiple  _testmultiphase  _testsinglephase  '
+                   '_ctypes_test  xxlimited  xxlimited_35  atexit  '
+                   'faulthandler  posix  _signal  _tracemalloc  _codecs  '
+                   '_collections  errno  _io  itertools  _sre  _thread  time  '
+                   '_typing  _weakref  _abc  _functools  _locale  _operator  '
+                   '_stat  _symtable  pwd',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  '
@@ -676,11 +710,24 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_io/textio.o Modules/_io/stringio.o  '
             'Modules/itertoolsmodule.o  Modules/_sre/sre.o  '
             'Modules/_threadmodule.o  Modules/timemodule.o  '
-            'Modules/_weakref.o  Modules/_abc.o  Modules/_functoolsmodule.o  '
-            'Modules/_localemodule.o  Modules/_operator.o  Modules/_stat.o  '
-            'Modules/symtablemodule.o  Modules/pwdmodule.o  '
-            'Modules/xxsubtype.o',
- 'MODSHARED_NAMES': '',
+            'Modules/_typingmodule.o  Modules/_weakref.o  Modules/_abc.o  '
+            'Modules/_functoolsmodule.o  Modules/_localemodule.o  '
+            'Modules/_operator.o  Modules/_stat.o  Modules/symtablemodule.o  '
+            'Modules/pwdmodule.o',
+ 'MODSHARED_NAMES': 'array _asyncio _bisect _contextvars _csv _heapq _json '
+                    '_lsprof _opcode _pickle _queue _random _struct '
+                    '_xxsubinterpreters _xxinterpchannels _zoneinfo audioop '
+                    'math cmath _statistics _datetime _decimal binascii _bz2 '
+                    '_lzma zlib _gdbm readline _md5 _sha1 _sha2 _sha3 _blake2 '
+                    'pyexpat _elementtree _codecs_cn _codecs_hk '
+                    '_codecs_iso2022 _codecs_jp _codecs_kr _codecs_tw '
+                    '_multibytecodec unicodedata _crypt fcntl grp mmap '
+                    'ossaudiodev _posixsubprocess resource select _socket spwd '
+                    'syslog termios _posixshmem _multiprocessing _ctypes '
+                    '_curses _curses_panel _sqlite3 _ssl _hashlib _uuid '
+                    'xxsubtype _xxtestfuzz _testbuffer _testinternalcapi '
+                    '_testcapi _testclinic _testimportmultiple _testmultiphase '
+                    '_testsinglephase _ctypes_test xxlimited xxlimited_35',
  'MODULE_ARRAY_STATE': 'yes',
  'MODULE_ATEXIT_LDFLAGS': '',
  'MODULE_AUDIOOP_LDFLAGS': '-lm',
@@ -691,6 +738,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_CMATH_DEPS': './Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
+ 'MODULE_DEPS_SHARED': 'Modules/config.c',
+ 'MODULE_DEPS_STATIC': 'Modules/config.c',
  'MODULE_ERRNO_LDFLAGS': '',
  'MODULE_FAULTHANDLER_LDFLAGS': '',
  'MODULE_FCNTL_LDFLAGS': '',
@@ -712,6 +761,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_PYEXPAT_DEPS': '\\ Modules/expat/libexpat.a',
  'MODULE_PYEXPAT_LDFLAGS': '-lm Modules/expat/libexpat.a',
  'MODULE_PYEXPAT_STATE': 'yes',
+ 'MODULE_READLINE_CFLAGS': '',
+ 'MODULE_READLINE_LDFLAGS': '-lreadline',
+ 'MODULE_READLINE_STATE': 'yes',
  'MODULE_RESOURCE_STATE': 'yes',
  'MODULE_SELECT_STATE': 'yes',
  'MODULE_SPWD_STATE': 'yes',
@@ -724,7 +776,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_XXLIMITED_35_STATE': 'yes',
  'MODULE_XXLIMITED_STATE': 'yes',
- 'MODULE_XXSUBTYPE_LDFLAGS': '',
+ 'MODULE_XXSUBTYPE_STATE': 'yes',
  'MODULE_ZLIB_CFLAGS': '',
  'MODULE_ZLIB_LDFLAGS': '-lz',
  'MODULE_ZLIB_STATE': 'yes',
@@ -752,12 +804,35 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
  'MODULE__BZ2_STATE': 'yes',
+ 'MODULE__CODECS_CN_DEPS': './Modules/cjkcodecs/mappings_cn.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_CN_STATE': 'yes',
+ 'MODULE__CODECS_HK_DEPS': './Modules/cjkcodecs/mappings_hk.h  '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_HK_STATE': 'yes',
+ 'MODULE__CODECS_ISO2022_DEPS': './Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                                './Modules/cjkcodecs/alg_jisx0201.h '
+                                './Modules/cjkcodecs/emu_jisx0213_2000.h '
+                                './Modules/cjkcodecs/multibytecodec.h '
+                                './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_ISO2022_STATE': 'yes',
+ 'MODULE__CODECS_JP_DEPS': './Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                           './Modules/cjkcodecs/alg_jisx0201.h '
+                           './Modules/cjkcodecs/emu_jisx0213_2000.h '
+                           './Modules/cjkcodecs/mappings_jp.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_JP_STATE': 'yes',
+ 'MODULE__CODECS_KR_DEPS': './Modules/cjkcodecs/mappings_kr.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_KR_STATE': 'yes',
  'MODULE__CODECS_LDFLAGS': '',
+ 'MODULE__CODECS_TW_DEPS': './Modules/cjkcodecs/mappings_tw.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_TW_STATE': 'yes',
  'MODULE__COLLECTIONS_LDFLAGS': '',
  'MODULE__CONTEXTVARS_STATE': 'yes',
@@ -765,11 +840,22 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CRYPT_LDFLAGS': '-lcrypt',
  'MODULE__CRYPT_STATE': 'yes',
  'MODULE__CSV_STATE': 'yes',
+ 'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow',
  'MODULE__CTYPES_DEPS': './Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_LDFLAGS': '-L/usr/lib/../lib -lffi -ldl',
+ 'MODULE__CTYPES_MALLOC_CLOSURE': '',
+ 'MODULE__CTYPES_STATE': 'yes',
  'MODULE__CTYPES_TEST_LDFLAGS': '-lm',
  'MODULE__CTYPES_TEST_STATE': 'yes',
+ 'MODULE__CURSES_CFLAGS': '-D_DEFAULT_SOURCE',
+ 'MODULE__CURSES_LDFLAGS': '-Wl,-O1 -lncursesw',
+ 'MODULE__CURSES_PANEL_CFLAGS': '-D_DEFAULT_SOURCE  -D_DEFAULT_SOURCE',
+ 'MODULE__CURSES_PANEL_LDFLAGS': '-Wl,-O1 -lpanelw -Wl,-O1 -lncursesw',
+ 'MODULE__CURSES_PANEL_STATE': 'yes',
+ 'MODULE__CURSES_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
+ 'MODULE__DBM_STATE': 'missing',
  'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
                            '-DANSI=1 -DHAVE_UINT128_T=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
@@ -798,8 +884,12 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_DEPS': './Modules/hashlib.h',
+ 'MODULE__MD5_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                       '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__MD5_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_MD5.h '
+                     'Modules/_hacl/Hacl_Hash_MD5.c',
  'MODULE__MD5_STATE': 'yes',
+ 'MODULE__MULTIBYTECODEC_DEPS': './Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
  'MODULE__MULTIPROCESSING_CFLAGS': '-I./Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
@@ -813,15 +903,19 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA1_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__SHA1_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_SHA1.h '
+                      'Modules/_hacl/Hacl_Hash_SHA1.c',
  'MODULE__SHA1_STATE': 'yes',
- 'MODULE__SHA256_DEPS': './Modules/hashlib.h',
- 'MODULE__SHA256_STATE': 'yes',
- 'MODULE__SHA3_DEPS': './Modules/_sha3/sha3.c ./Modules/_sha3/sha3.h '
-                      './Modules/hashlib.h',
+ 'MODULE__SHA2_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__SHA2_DEPS': './Modules/hashlib.h \\ '
+                      'Modules/_hacl/libHacl_Hash_SHA2.a',
+ 'MODULE__SHA2_STATE': 'yes',
+ 'MODULE__SHA3_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_SHA3.h '
+                      'Modules/_hacl/Hacl_Hash_SHA3.c',
  'MODULE__SHA3_STATE': 'yes',
- 'MODULE__SHA512_DEPS': './Modules/hashlib.h',
- 'MODULE__SHA512_STATE': 'yes',
  'MODULE__SIGNAL_LDFLAGS': '',
  'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
                         './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
@@ -849,7 +943,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': './Modules/testcapi_long.h',
+ 'MODULE__TESTCAPI_DEPS': './Modules/_testcapi/testcapi_long.h '
+                          './Modules/_testcapi/parts.h '
+                          './Modules/_testcapi/util.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
@@ -858,11 +954,13 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__THREAD_LDFLAGS': '',
  'MODULE__TKINTER_STATE': 'missing',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
+ 'MODULE__TYPING_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
  'MODULE__UUID_CFLAGS': '-I/usr/include/uuid',
  'MODULE__UUID_LDFLAGS': '-luuid',
  'MODULE__UUID_STATE': 'yes',
  'MODULE__WEAKREF_LDFLAGS': '',
+ 'MODULE__XXINTERPCHANNELS_STATE': 'yes',
  'MODULE__XXSUBINTERPRETERS_STATE': 'yes',
  'MODULE__XXTESTFUZZ_STATE': 'yes',
  'MODULE__ZONEINFO_STATE': 'yes',
@@ -871,12 +969,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '',
- 'OPENSSL_LDFLAGS': '',
- 'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
- 'OTHER_LIBTOOL_OPT': '',
+ 'OPT': '-DNDEBUG -g -O3 -Wall',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -910,29 +1003,29 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-                             '-std=c11 -Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g '
+                             '-O3 -Wall -std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall',
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall',
  'PY_CFLAGS_NODIST': '-std=c11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall -std=c11 '
-                   '-Wextra -Wno-unused-parameter '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+                   '-std=c11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,-O1',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 0,
- 'PY_FORMAT_SIZE_T': '"z"',
+ 'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '-Wl,-O1 -Wl,-O1',
  'PY_LDFLAGS_NODIST': '',
  'PY_LDFLAGS_NOLTO': '-Wl,-O1 -Wl,-O1',
@@ -940,8 +1033,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall -std=c11 '
-                        '-Wextra -Wno-unused-parameter '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 '
+                        '-Wall -std=c11 -Wextra -Wno-unused-parameter '
                         '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
@@ -954,13 +1047,92 @@ build_time_vars = {'ABIFLAGS': '',
  'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'READELF': 'readelf',
+ 'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
  'RUNSHARED': '',
  'SCRIPTDIR': '/usr/lib',
+ 'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
+ 'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
+ 'SCRIPT_PYDOC': 'build/scripts-3.12/pydoc3.12',
  'SETPGRP_HAVE_ARG': 0,
- 'SHELL': '/bin/sh',
+ 'SHAREDMODS': 'Modules/array.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_asyncio.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_bisect.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_contextvars.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_csv.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_heapq.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_json.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_lsprof.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_opcode.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_pickle.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_queue.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_random.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_struct.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_xxsubinterpreters.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_xxinterpchannels.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_zoneinfo.cpython-312-x86_64-linux-gnu.so '
+               'Modules/audioop.cpython-312-x86_64-linux-gnu.so '
+               'Modules/math.cpython-312-x86_64-linux-gnu.so '
+               'Modules/cmath.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_statistics.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_datetime.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_decimal.cpython-312-x86_64-linux-gnu.so '
+               'Modules/binascii.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_bz2.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_lzma.cpython-312-x86_64-linux-gnu.so '
+               'Modules/zlib.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_gdbm.cpython-312-x86_64-linux-gnu.so '
+               'Modules/readline.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_md5.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_sha1.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_sha2.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_sha3.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_blake2.cpython-312-x86_64-linux-gnu.so '
+               'Modules/pyexpat.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_elementtree.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_codecs_cn.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_codecs_hk.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_codecs_iso2022.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_codecs_jp.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_codecs_kr.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_codecs_tw.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_multibytecodec.cpython-312-x86_64-linux-gnu.so '
+               'Modules/unicodedata.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_crypt.cpython-312-x86_64-linux-gnu.so '
+               'Modules/fcntl.cpython-312-x86_64-linux-gnu.so '
+               'Modules/grp.cpython-312-x86_64-linux-gnu.so '
+               'Modules/mmap.cpython-312-x86_64-linux-gnu.so '
+               'Modules/ossaudiodev.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_posixsubprocess.cpython-312-x86_64-linux-gnu.so '
+               'Modules/resource.cpython-312-x86_64-linux-gnu.so '
+               'Modules/select.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_socket.cpython-312-x86_64-linux-gnu.so '
+               'Modules/spwd.cpython-312-x86_64-linux-gnu.so '
+               'Modules/syslog.cpython-312-x86_64-linux-gnu.so '
+               'Modules/termios.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_posixshmem.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_multiprocessing.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_ctypes.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_curses.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_curses_panel.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_sqlite3.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_ssl.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_hashlib.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_uuid.cpython-312-x86_64-linux-gnu.so '
+               'Modules/xxsubtype.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_xxtestfuzz.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_testbuffer.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_testinternalcapi.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_testcapi.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_testclinic.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_testimportmultiple.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_testmultiphase.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_testsinglephase.cpython-312-x86_64-linux-gnu.so '
+               'Modules/_ctypes_test.cpython-312-x86_64-linux-gnu.so '
+               'Modules/xxlimited.cpython-312-x86_64-linux-gnu.so '
+               'Modules/xxlimited_35.cpython-312-x86_64-linux-gnu.so',
+ 'SHELL': '/bin/sh -e',
  'SHLIBS': '-ldl',
  'SHLIB_SUFFIX': '.so',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
@@ -983,11 +1155,11 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-311-x86_64-linux-gnu',
+ 'SOABI': 'cpython-312-x86_64-linux-gnu',
  'SRCDIRS': 'Modules   Modules/_blake2   Modules/_ctypes   Modules/_decimal   '
-            'Modules/_decimal/libmpdec   Modules/_io   '
-            'Modules/_multiprocessing   Modules/_sha3   Modules/_sqlite   '
-            'Modules/_sre   Modules/_xxtestfuzz   Modules/cjkcodecs   '
+            'Modules/_decimal/libmpdec   Modules/_hacl   Modules/_io   '
+            'Modules/_multiprocessing   Modules/_sqlite   Modules/_sre   '
+            'Modules/_testcapi   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
@@ -1004,21 +1176,20 @@ build_time_vars = {'ABIFLAGS': '',
  'TESTPYTHON': './python -E',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python -E ./Tools/scripts/run_tests.py',
- 'TESTSUBDIRS': 'ctypes/test \\',
+ 'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
  'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
- 'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': './Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/build/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.11',
+ 'VERSION': '3.12',
  'WASM_ASSETS_DIR': './usr',
- 'WASM_STDLIB': './usr/lib/python3.11/os.py',
+ 'WASM_STDLIB': './usr/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
@@ -1033,8 +1204,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/src/Python-3.11.14',
- 'abs_srcdir': '/src/Python-3.11.14',
+ 'abs_builddir': '/src/Python-3.12.12',
+ 'abs_srcdir': '/src/Python-3.12.12',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
